Learn R Programming

polarisR (version 0.1.4)

four_clusters: Four Clusters Simulated Dataset

Description

This dataset (four_clusters) contains simulated data with four distinct clusters, each generated using different shapes and scales. It is ideal for demonstrating clustering algorithms and visualization techniques.

Usage

four_clusters

Arguments

Format

A data frame with 2000 rows and 4 variables:

x1

Numeric. First feature coordinate.

x2

Numeric. Second feature coordinate.

x3

Numeric. Third feature coordinate.

x4

Numeric. Fourth feature coordinate.

cluster

Factor. The cluster label (1, 2, 3, or 4).

Details

Four Clusters Simulated Dataset

References

Gamage J, Cook D, Harrison P, Lydeamore M, Talagala T (2025).cardinalR: Collection of Data Structures. R package version 0.1.10, https://github.com/JayaniLakshika/cardinalR.

Examples

Run this code
data(four_clusters)
head(four_clusters)
dim(four_clusters)

Run the code above in your browser using DataLab